<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="83"/>
        <source>Enter the number to configure: </source>
        <translation>Ingrese el número para configurar:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="88"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="16"/>
        <source>Loading packages...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="17"/>
        <source>%1/%2 loaded</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="20"/>
        <source>Initializing...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="17"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="102"/>
        <source>Package Installer</source>
        <translation>Instalador de paquetes</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="110"/>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="131"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="539"/>
        <source>Installing other packages... Please open it later.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="543"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="545"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="547"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="625"/>
        <source>The deb package may be broken</source>
        <translation>El paquete deb puede estar roto</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="633"/>
        <source>You can only install local deb packages</source>
        <translation>Solo puedes instalar paquetes deb descargados</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="647"/>
        <source>Already Added</source>
        <translation>Ya agregado</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="656"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1 aún no existe, vuelva a seleccionar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="331"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="663"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="792"/>
        <source>Bulk Install</source>
        <translation>Instalación en masa</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="85"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="102"/>
        <source>Installation failed, please check your network connection</source>
        <translation>La instalación falló, compruebe su conexión de red</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="87"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>La instalación falló: compruebe las actualizaciones en el centro de control</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="90"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="94"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="106"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>La instalación falló, espacio insuficiente en disco</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="111"/>
        <source>No digital signature</source>
        <translation>Sin firma digital</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="115"/>
        <source>Invalid digital signature</source>
        <translation>Firma digital inválida</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="122"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="607"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1524"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>El administrador ha establecido políticas para evitar la instalación de este paquete.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="127"/>
        <source>Installation Failed</source>
        <translation>La instalación falló</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="611"/>
        <source>Failed to install %1</source>
        <translation>La instalación de %1 falló</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="883"/>
        <source>Failed to install %1: no valid digital singature</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="919"/>
        <source>Unable to install - no digital signature</source>
        <translation>No se puede instalar, no tiene firma digital</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="920"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>Por favor active el moda desarrollador en el Centro de control e intente de nuevo. ¿Continuar?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="923"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="924"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="879"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="976"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1526"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1012"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>Este paquete no tiene una firma digital válida. ¿Continuar con la instalación?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1014"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1015"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="877"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="973"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1523"/>
        <source>Unable to install</source>
        <translation>Incapaz de instalar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="974"/>
        <source>This package does not have a valid digital signature</source>
        <translation>Este paquete no tiene una firma digital válida</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="612"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="617"/>
        <source>Broken dependencies: %1</source>
        <translation>Dependencias rotas: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="119"/>
        <source>Authentication failed</source>
        <translation>La autenticación falló</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="605"/>
        <source>Unmatched package architecture</source>
        <translation>Difiere la arquitectura del paquete </translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="60"/>
        <source>Drag deb packages here</source>
        <translation>Arrastre los paquetes deb aquí</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="102"/>
        <source>Select File</source>
        <translation>Seleccionar archivo</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="33"/>
        <source>Show details</source>
        <translation>Mostrar detalles</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="33"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Colapsar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="171"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="172"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Finalizar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="174"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="464"/>
        <source>Dependencies in the repository</source>
        <translation>Dependencias en el repositorio</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="470"/>
        <source>Missing dependencies</source>
        <translation>Dependencias que faltan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="519"/>
        <source>Installing dependencies: %1</source>
        <translation>Instalando dependencias: %1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="82"/>
        <source>Same version installed</source>
        <translation>La misma versión está instalada</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="85"/>
        <source>Earlier version installed: %1</source>
        <translation>Una versión anterior está instalada: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="89"/>
        <source>Later version installed: %1</source>
        <translation>Una versión más nueva está instalada: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="94"/>
        <source>Unmatched package architecture</source>
        <translation>Difiere la arquitectura del paquete </translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="19"/>
        <source>Select all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="20"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Instalar</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="60"/>
        <source>Installing</source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="64"/>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="72"/>
        <source>Failed</source>
        <translation>Ha fallado</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="68"/>
        <source>Waiting</source>
        <translation>Esperando</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="233"/>
        <source>Same version installed</source>
        <translation>La misma versión está instalada</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="236"/>
        <source>Later version installed: %1</source>
        <translation>Una versión más nueva está instalada: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="239"/>
        <source>Earlier version installed: %1</source>
        <translation>Una versión anterior está instalada: %1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="166"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="30"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="45"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="46"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Colapsar</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>Comprobar las firmas digitales si el modo desarrollador está activado</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="708"/>
        <source>Collapse</source>
        <translation>Colapsar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="333"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="804"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="967"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="807"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="970"/>
        <source>Later version installed: %1</source>
        <translation>Una versión más nueva está instalada: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="809"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="972"/>
        <source>Downgrade</source>
        <translation>Degradar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="812"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="975"/>
        <source>Earlier version installed: %1</source>
        <translation>Una versión anterior está instalada: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="877"/>
        <source>Installing dependencies: %1</source>
        <translation>Instalando dependencias: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1012"/>
        <source>Failed to install %1</source>
        <translation>La instalación de %1 falló</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="178"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="325"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="329"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>Quitar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="337"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="341"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Atrás</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="345"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Finalizar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="680"/>
        <source>Installed successfully</source>
        <translation>Instalación exitosa</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="685"/>
        <source>Uninstalled successfully</source>
        <translation>Desinstalación exitosa</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="699"/>
        <source>Uninstall Failed</source>
        <translation>La desinstalación falló</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="728"/>
        <source>Dependencies in the repository</source>
        <translation>Dependencias en el repositorio</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="734"/>
        <source>Missing dependencies</source>
        <translation>Dependencias que faltan</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="814"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="977"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="166"/>
        <source>Name: </source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="803"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="966"/>
        <source>Same version installed</source>
        <translation>La misma versión está instalada</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="45"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="526"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="551"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="679"/>
        <source>Show details</source>
        <translation>Mostrar detalles</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="30"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="46"/>
        <source>Show dependencies</source>
        <translation>Mostrar las dependencias</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="576"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="684"/>
        <source>Show details</source>
        <translation>Mostrar detalles</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Show related packages</source>
        <translation>Mostrar paquetes relacionados</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Colapsar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="112"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>¿Está seguro de desinstalar %1?
Todas las dependencias también se eliminarán</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="114"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>¿Está seguro de que quiere desinstalar %1?
El sistema u otras aplicaciones tal vez no funcionen correctamente</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="47"/>
        <location filename="../src/deb-installer/main.cpp" line="48"/>
        <source>Package Installer</source>
        <translation>Instalador de paquetes</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>Instalador de paquetes de Deepin ayuda a instalar y eliminar paquetes locales, y admite instalación en masa.</translation>
    </message>
</context>
</TS>